﻿using System;
using System.Windows.Forms;

using DevExpress.Utils;
using DevExpress.XtraEditors;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : XtraForm
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            this.showInformationMessageBoxButton.Click  += showInformationMessageBoxButton_Click;
            this.showErrorMessageBoxButton.Click        += showErrorMessageBoxButton_Click;
            this.showConfirmationMessageBoxButton.Click += showConfirmationMessageBoxButton_Click;
            this.showAutoCloseMessageBoxButton.Click    += showAutoCloseMessageBoxButton_Click;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region INFORMATION 메시지 박스 표시 버튼 클릭시 처리하기 - showInformationMessageBoxButton_Click(sender, e)

        /// <summary>
        /// INFORMATION 메시지 박스 표시 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void showInformationMessageBoxButton_Click(object sender, EventArgs e)
        {
            IWin32Window            owner         = this;
            string                  text          = "<b>선택된 항목이 없습니다.</b><br>1개 이상의 항목을 선택해 주시기 바랍니다.";
            string                  caption       = "INFORMATION";
            MessageBoxButtons       buttons       = MessageBoxButtons.OK;
            MessageBoxIcon          icon          = MessageBoxIcon.Information;
            MessageBoxDefaultButton defaultButton = MessageBoxDefaultButton.Button1;
            DefaultBoolean          allowHtmlText = DefaultBoolean.True;

            XtraMessageBox.Show(owner, text, caption, buttons, icon, defaultButton, allowHtmlText);
        }

        #endregion
        #region ERROR 메시지 박스 표시 버튼 클릭시 처리하기 - showErrorMessageBoxButton_Click(sender, e)

        /// <summary>
        /// ERROR 메시지 박스 표시 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void showErrorMessageBoxButton_Click(object sender, EventArgs e)
        {
            IWin32Window            owner         = this;
            string                  text          = "<b>자료 삭제시 에러가 발생했습니다.</b><br>계속해서 에러가 발생하면 관리자에게 문의해 주시기 바랍니다.";
            string                  caption       = "ERROR";
            MessageBoxButtons       buttons       = MessageBoxButtons.OK;
            MessageBoxIcon          icon          = MessageBoxIcon.Error;
            MessageBoxDefaultButton defaultButton = MessageBoxDefaultButton.Button1;
            DefaultBoolean          allowHtmlText = DefaultBoolean.True;

            XtraMessageBox.Show(owner, text, caption, buttons, icon, defaultButton, allowHtmlText);
        }

        #endregion
        #region CONFIRMATION 메시지 박스 표시 버튼 클릭시 처리하기 - showConfirmationMessageBoxButton_Click(sender, e)

        /// <summary>
        /// CONFIRMATION 메시지 박스 표시 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void showConfirmationMessageBoxButton_Click(object sender, EventArgs e)
        {
            IWin32Window            owner         = this;
            string                  text          = "<b>선택한 자료를 삭제하시겠습니까?</b><br>삭제시 자료를 복구할 수 없습니다.";
            string                  caption       = "CONFIRMATION";
            MessageBoxButtons       buttons       = MessageBoxButtons.YesNo;
            MessageBoxIcon          icon          = MessageBoxIcon.Question;
            MessageBoxDefaultButton defaultButton = MessageBoxDefaultButton.Button2;
            DefaultBoolean          allowHtmlText = DefaultBoolean.True;

            DialogResult result = XtraMessageBox.Show(owner, text, caption, buttons, icon, defaultButton, allowHtmlText);

            if(result == DialogResult.Yes)
            {
                // 작업을 처리합니다.
            }
        }

        #endregion
        #region 자동 종료 메시지 박스 표시 버튼 클릭시 처리하기 - showAutoCloseMessageBoxButton_Click(sender, e)

        /// <summary>
        /// 자동 종료 메시지 박스 표시 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void showAutoCloseMessageBoxButton_Click(object sender, EventArgs e)
        {
            XtraMessageBoxArgs xtraMessageBoxArgs = new XtraMessageBoxArgs();

            xtraMessageBoxArgs.Owner                                     = this;
            xtraMessageBoxArgs.Text                                      = "<b>진행중인 작업이 존재합니다.</b><br>이 메시지는 3초후 자동 종료합니다.";
            xtraMessageBoxArgs.Caption                                   = "INFORMATION";
            xtraMessageBoxArgs.Buttons                                   = new DialogResult[] { DialogResult.OK };
            xtraMessageBoxArgs.DefaultButtonIndex                        = 0;
            xtraMessageBoxArgs.AllowHtmlText                             = DefaultBoolean.True;
            xtraMessageBoxArgs.AutoCloseOptions.Delay                    = 3000;
            xtraMessageBoxArgs.AutoCloseOptions.ShowTimerOnDefaultButton = true;

            DialogResult result = XtraMessageBox.Show(xtraMessageBoxArgs);

            if(result == DialogResult.OK)
            {
                // 작업을 처리합니다.
            }
        }

        #endregion
    }
}